@@ -13,7 +13,7 @@ except ImportError:  # pragma: nocover
     from urllib import urlencode
 from . import exceptions, utils
 
-__version__ = "0.8.3"
+__version__ = "0.8.4"
 
 _log = logging.getLogger(__name__)
 
@@ -56,6 +56,8 @@ class Client(utils._SetEnv):
                     raise exceptions.BICIBANMismatch(message)
                 if "ould not interpret numbers after plus-sign" in message:
                     raise exceptions.InvalidPhoneNumber(message)
+                if "equired fields are:" in message:
+                    raise exceptions.MissingFields(message)
             if rsp.status_code == 401:
                 raise exceptions.Unauthorized(rsp.status_code, message)
             if rsp.status_code == 422:
@@ -218,7 +220,7 @@ class Account(_UpdateFromKwargsMixin):
         try:
             cpt = self.client._cptbyaccount[destid]
             if cpt.accounts[destid].currency != currency:
-                raise ValueError(
+                raise exceptions.CurrencyMismatch(
                     "Currency {} does not match the destination currency: {}".format(
                         currency, cpt.accounts[destid].currency
                     )
@@ -230,7 +232,7 @@ class Account(_UpdateFromKwargsMixin):
             try:
                 cpt = self.client.counterparties[destid]
             except KeyError:
-                raise ValueError(
+                raise exceptions.DestinationNotFound(
                     "Cannot find {:s} either among counterparties, their accounts or our own accounts".format(
                         destid
                     )
@@ -439,6 +441,7 @@ class CounterpartyExternalAccount(CounterpartyAccount):
     email = ""
     bank_country = ""
     recipient_charges = ""
+    bsb_code = ""
 
     def __repr__(self):
         return "<CounterpartyExternalAccount {}>".format(self.id)
